# jQuery.syoInputGrid
*Requires [jQuery](http://jquery.com/)* 

## Description
Add/Remove inputs from the given selector(container)
Actually supports input[type='text'] and select[type='select-one']

## Example/Properties
<pre>
//Add 1 item
$("#container").syoInputGrid({
    
    /*
     * itemTemplate (String)
     * Template used to create the inputs
     * The $i var will print the zero-based index
     */
    itemTemplate: "&lt;div class='custom-item'&gt;&lt;input type='text' name='input[$i]' id='input[$i]' /&gt;&lt;/div&gt;",
    
    /*
     * emptyMessage (String)
     * Custom message for when there's no item left in the container
     * default: empty string
     */
    emptyMessage: "Custom message",

    /*
     * items (Number)
     * Quantity of items to be created upon instantiation
     * default: 1
     */
    items: 1,
    
    /*
     * type (String)
     * The type of input that is being created
     * This is used to enable/disable the specified input inside the container
     * Values allowed: "text", "select-one"
     * default: "text" 
     */
     type: "text"
});
</pre>

## Methods

### Add
Add a new item to the given container

#### .syoInputGrid("add", [Number quantity])
Add _quantity_ items to the selector
<pre>
$("#container").syoInputGrid("add", 5);
</pre>

#### .syoInputGrid("add", [String[] array)
Add _array.length_ items to the container and set the value of the first input of each item as the string of the respective _array_ index
<pre>
$("#container").syoInputGrid("add", ["value1", "value2", "value3"]);
</pre>

#### .syoInputGrid("add", [Object[] attributesArray])
Add _attributesArray.length_ items to the container and set the attributes of the first input of each item according to the object of the respective _attributesArray_ index
<pre>
var array = [{
        title: "A title"
      }, {
        value: "Some value",
        "class": "someClass"
      }];

$("#container").syoInputGrid("add", array);
</pre>

### Remove

#### .syoInputGrid("remove")
Remove the last item from the container if at least one exists

#### .syoInputGrid("remove", "all")
Remove all items from the container if at least one exists

### Disabled

#### .syoInputGrid("disabled")
Disables all the inputs inside the selector

### Enabled

#### .syoInputGrid("enabled")
Enables all the inputs inside the selector

## Changelog
* 0.12 - 23/07/2012 - Allows the possibility to work with "select-one" elements
* 0.11 - 31/05/2012 - Add 'remove' passing an index. If this is used, the internal count do not decrement
* 0.11 - 31/05/2012 - if 'items' and 'ignoreFirst' are defined, ignoreFirst is ignored
* 0.11	- 31/05/2012 - 'items' property should receive the same value as the 'add' method argument
* 0.10	- 30/05/2012 - If emptyMessage was not specified then do not print anything
* 0.9.2	- 30/05/2012 - On init we should calculate the internal index even if there's no element to be added cause we can use the method "remove" into existing items
* 0.9.1 - 30/05/2012 - Fix emptyMessage being appended even when there's one children on init
* 0.9 	- 29/05/2012 - Allow the possibility to pass an object to the array on "add" method. The object represents a set of attributes to set to the first input:text
* 0.8 	- 29/12/2012 - Check emptyMessage on init (if there's no children print the message)
* 0.7 	- 29/05/2012 - Use .andSelf() instead of .filter() and then .find()
* 0.6 	- 29/05/2012 - Check the children at the init and increments the internal index accordingly
* 0.6 	- 29/05/2012 - Should consider only input:text while setting the value through passing an array into "add" method
* 0.6 	- 29/05/2012 - Add emptyMessage property
* 0.5 	- 28/05/2012 - Add the disabled/enabled methods
* 0.4 	- 28/05/2012 - Add $().syoInputGrid("remove", "all") to remove all the inputs from the container and reset the index count
* 0.3 	- 28/05/2012 - Add ignoreFirst option to ignore the first default item created on initialization
* 0.2 	- 28/05/2012 - Allows the possibility to pass an array to the "add" method
* 0.1 	- 25/05/2012 - Initial version