/*!
 * jQuery syoInputGrid v0.12.1 - Fagner Martins Brack
 * https://github.com/Syonet/syo-input-grid
 */
(function($, undefined) {
	
	"use strict";
	
	function option(key, $selector) {
		return $selector.data( "options" )[ key ];
	}
	
	var dataPrefix = "syoGrid",
		dataLastId = dataPrefix + "LastId",
		dataDisabled = dataPrefix + "Disabled",
		emptyMsgClass = "grid-custom-msg";
	
	var _methods = {
		add: function( arg0, init ) {
			
			var itemTemplate, content, i, _i, qt, arr, arrVal, emptyMsgVal, $content, $input,
				$children = this.children(),
				startID = init === true ? $children.length : this.data( dataLastId ) || 0;
			
			this.data(dataLastId, startID);
			
			//Imediate return if no item should be created
			if( arg0 === 0 || (arg0 && arg0.length === 0) ) {
				if( init && !$children.length ) {
					emptyMsgVal = option( "emptyMessage", this );
					if( typeof emptyMsgVal === "string" ) {
						this.append( "<div class='" + emptyMsgClass + "'>" + emptyMsgVal + "</div>" );
					}
				}
			return;
			}
			
			//Plugin should not be disabled
			if( this.data(dataDisabled) !== true ) {
				
				itemTemplate = option( "itemTemplate", this );
				content = "";
				
				$children = this.children();
				if( $children.length ) {
					$children.filter( "div." + emptyMsgClass ).remove();
				}
				
				i = startID;
				
				if( $.isArray(arg0) ) {
					arr = arg0;
					qt = arg0.length;
					_i = 0;
					
					for( ; i<startID + qt; i++ ) {
						$content = $( content.concat(itemTemplate.replaceAll( "$i", i )) );
						$input = _methods._getInputs( $content, 0 );
						
						this.append( $content );
						
						if( $input.length ) {
							arrVal = arr[ _i++ ];
							if( typeof arrVal === "string" ) {
								$input.val( arrVal );
							} else {
								$input.attr( arrVal );
							}
						}
					}
				} else {
					qt = arg0 || 1;
					
					for( ; i<startID + qt; i++ ) {
						content = content.concat( itemTemplate.replaceAll("$i", i) );
					}
					
					this.append( content );
				}
				
				this.data( dataLastId, startID + qt );
			}
		},
		_getInputs: function( $content, i ) {
			var opt = $content.data( "options" ),
				$inputs = $();
			
			if( $content ) {
				if( opt && opt.type === "select-one" ) {
					$inputs = $content.find( "select" ).andSelf().filter(function() {
						return this.nodeName.toLowerCase() === "select" && this.type === "select-one";
					});
				} else {
					$inputs = $content.find( "input" ).andSelf().filter(function() {
						return this.nodeName.toLowerCase() === "input" && this.type === "text";
					});
				}
			}
			
			if( typeof i === "number" ) {
				$inputs = $inputs.slice( i, i + 1 );
			}
			
		return $inputs;
		},
		remove: function( arg0 ) {
			
			var lastID, emptyMsgVal, $input, $children;
			
			//Plugin should not be disabled
			if( this.data(dataDisabled) !== true ) {
			
				lastID = this.data( dataLastId );
				
				if( arg0 === "all" ) {
					this.empty();
					this.data( dataLastId, (lastID = 0) );
				} else {
					$children = this.children( ":not(div." + emptyMsgClass + ")" );
					if( typeof arg0 === "number" ) {
						$input = $children.slice( arg0, arg0 + 1 );
						if( $input.length ) {
							$children = $children.not( $input.remove() );
						}
					} else {
						$input = $children.filter( ":last" );
						if( $input.length ) {
							$input.remove();
							this.data( dataLastId, (lastID = lastID - 1) );
						}
					}
				}
				
				if( lastID === 0 || $children.length === 0 ) {
					emptyMsgVal = option( "emptyMessage", this );
					if( typeof emptyMsgVal === "string" ) {
						this.append( "<div class='" + emptyMsgClass + "'>" + emptyMsgVal + "</div>" );
					}
				}
			}
		},
		
		destroy: function() {
			this
				.removeData(dataLastId)
				.removeData(dataDisabled)
				.removeData(dataPrefix)
				.empty();
		},
		
		disabled: function() {
			this
				.data( dataDisabled, true );
			
			_methods
				._getInputs( this )
					.prop( "disabled", true );
		},
		
		enabled: function() {
			this
				.removeData( dataDisabled );
			
			_methods.
				_getInputs( this )
					.prop( "disabled", false );
		}
	};
	
	$.fn.syoInputGrid = function( args, val ) {
		
		var items,
			$selector = this.slice( 0, 1 );
		
		//If no selector just ignore the rest
		if( $selector.length ) {
			
			if( $selector.data(dataPrefix) ) {
				if( args in _methods ) {
					_methods[ args ].call( $selector, val );
				} else {
					throw new Error( "Method .syoInputGrid('" + args + "') not found." );
				}
			} else {
				
				$selector.data( "options", $.extend({
					itemTemplate: "<input type='text' name='grid[$i]' id='grid[$i]' />"
				}, args) );
				
				$selector.data( dataPrefix, true );
				
				items = option( "items", $selector );
				if( items === undefined && option( "ignoreFirst", $selector ) === true ) {
					items = 0;
				}
				
				_methods.add.call( $selector, items, true );
			}
		}
		
	return this;
	};
})(jQuery);