module("Methods");
test("Method add", function() {
	$("#qunit-fixture").syoInputGrid();
	$("#qunit-fixture").syoInputGrid("add", 2);
	
	deepEqual($("#qunit-fixture").children("input").length, 3, "Should have three inputs");
	
	$("#qunit-fixture").syoInputGrid("add", 2);
	
	var i = 0;
	$("#qunit-fixture > input").each(function() {
		var $this = $(this);
		deepEqual($this.attr("id"), "grid[" + i + "]", "The var $i should be recalculated");
		
		i++;
	});
	
	$("#qunit-fixture").syoInputGrid("destroy");
});
test("Method add (passing array)", function() {
	$("#qunit-fixture").syoInputGrid({
		itemTemplate: "<input type='text' class='test-first' i='$i' value=''/><input type='text' i='$i' class='test-second' value=''/>"
	});
	$("#qunit-fixture").syoInputGrid("add", ["first val", "second val"]);
	
	//start from (2, 3) to ignore the first 2 inputs
	deepEqual($("#qunit-fixture > input").slice(2, 3).val(), "first val", "The first input value is correct");
	deepEqual($("#qunit-fixture > input").slice(3, 4).val(), "", "The second input value is correct");
	deepEqual($("#qunit-fixture > input").slice(4, 5).val(), "second val", "The third input value is correct");
	deepEqual($("#qunit-fixture > input").slice(5, 6).val(), "", "The fourth input value is correct");
	
	$("#qunit-fixture").syoInputGrid("destroy");
});
test("Method add (passing array with input inside container)", function() {
	$("#qunit-fixture").syoInputGrid({
		itemTemplate: "<div><input type='text' class='test-first' i='$i' value=''/></div><div><input type='text' i='$i' class='test-second' value=''/></div>"
	});
	$("#qunit-fixture").syoInputGrid("add", ["first val", "second val"]);
	
	//start from (2, 3) to ignore the first 2 inputs
	deepEqual($("#qunit-fixture input").slice(2, 3).val(), "first val", "The first input value is correct");
	deepEqual($("#qunit-fixture input").slice(3, 4).val(), "", "The second input value is correct");
	deepEqual($("#qunit-fixture input").slice(4, 5).val(), "second val", "The third input value is correct");
	deepEqual($("#qunit-fixture input").slice(5, 6).val(), "", "The fourth input value is correct");
	
	$("#qunit-fixture").syoInputGrid("destroy");
});
test("Method add (passing array - should not set the value in other input than input:text)", function() {
	$("#qunit-fixture").syoInputGrid({
		itemTemplate: "<div><input type='button' class='test-first' i='$i' value=''/></div><div><input type='button' class='test-first' i='$i' value=''/></div><div><input type='text' i='$i' class='test-second' value=''/></div>"
	});
	$("#qunit-fixture").syoInputGrid("add", ["val"]);
	
	//start from (3, 4) to ignore the first 3 inputs
	deepEqual($("#qunit-fixture input").slice(3, 4).val(), "", "The first input value is correct");
	deepEqual($("#qunit-fixture input").slice(4, 5).val(), "", "The second input value is correct");
	deepEqual($("#qunit-fixture input").slice(5, 6).val(), "val", "The third input value is correct");
	
	$("#qunit-fixture").syoInputGrid("destroy");
});
test("Method add (passing array with an object representing a set of attributes to the first input:text)", function() {
	$("#qunit-fixture").syoInputGrid({ itemTemplate: "<input type='text'/>", ignoreFirst: true });
	$("#qunit-fixture").syoInputGrid("add", [{
		id: "test-id",
		name: "test-name[0]",
		value: "test-value",
		"class": "aClass"
	}]);
	
	deepEqual($("#qunit-fixture input").attr("id"), "test-id", "id is correct");
	deepEqual($("#qunit-fixture input").attr("name"), "test-name[0]", "name is correct");
	deepEqual($("#qunit-fixture input").val(), "test-value", "value is correct");
	deepEqual($("#qunit-fixture input").attr("class"), "aClass", "class is correct");
	
	$("#qunit-fixture").syoInputGrid("destroy");
});
test("Method remove (remove last input)", function() {
	var i;
	
	$("#qunit-fixture").syoInputGrid();
	$("#qunit-fixture").syoInputGrid("add", 2);
	$("#qunit-fixture").find("input:last").addClass("test");
	$("#qunit-fixture").syoInputGrid("remove");
	
	deepEqual($("#qunit-fixture").find("input:last.test").length, 0, "The last input should be removed");
	
	$("#qunit-fixture").syoInputGrid("add", 2);
	i = 0;
	$("#qunit-fixture > input").each(function() {
		deepEqual($(this).attr("id"), "grid[" + i + "]", "The var $i should be recalculated for the next add after remove");
		i++;
	});
	
	$("#qunit-fixture").syoInputGrid("remove"); //1
	$("#qunit-fixture").syoInputGrid("remove"); //2
	$("#qunit-fixture").syoInputGrid("remove"); //3
	$("#qunit-fixture").syoInputGrid("remove"); //4
	$("#qunit-fixture").syoInputGrid("remove"); //5 - no item
	
	$("#qunit-fixture").syoInputGrid("add", 2);
	i = 0;
	$("#qunit-fixture > input").each(function() {
		deepEqual($(this).attr("id"), "grid[" + i + "]", "Should not let the ID go < 0");
		i++;
	});
	
	$("#qunit-fixture").syoInputGrid("destroy");
});
test("Method remove (remove last input) - When there is children it should update the internal index", function() {
	$("#qunit-fixture").append("<div class='an-item'></div>");
	$("#qunit-fixture").syoInputGrid({
		itemTemplate: "<div class='an-item'></div>",
		emptyMessage: "Custom message",
		ignoreFirst: true
	});
	$("#qunit-fixture").syoInputGrid("remove");
	
	deepEqual($("#qunit-fixture div.grid-custom-msg").length, 1, "The emptyMessage should be appended");
	
	$("#qunit-fixture").syoInputGrid("destroy");
});
test("Method remove ('all') - Remove all inputs and reset the index counter", function() {
	var i = 0;
	
	$("#qunit-fixture").syoInputGrid();
	$("#qunit-fixture").syoInputGrid("add", 2);
	$("#qunit-fixture").syoInputGrid("remove", "all");
	
	expect(0);
	$("#qunit-fixture > input").each(function() {
		ok(false, "Should have no input");
	});
	
	$("#qunit-fixture").syoInputGrid("add", 2);
	
	i = 0;
	expect(2);
	$("#qunit-fixture > input").each(function() {
		deepEqual($(this).attr("id"), "grid[" + i + "]", "The id should be reset");
		i++;
	});
	
	$("#qunit-fixture").syoInputGrid("destroy");
});
test("Method remove(index)", function() {
	$("#qunit-fixture").syoInputGrid({
		itemTemplate: "<input type='text' value='$i' />",
		items: 5
	});
	$("#qunit-fixture").syoInputGrid("remove", 0);
	
	deepEqual($("#qunit-fixture input:eq(0)").val(), "1", "The input has been sucessfully removed");
	
	$("#qunit-fixture").syoInputGrid("destroy");
});
test("Method remove(index) - If removing an item by index the internal count should not decrement", function() {
	$("#qunit-fixture").syoInputGrid({
		itemTemplate: "<input type='text' value='$i' />",
		items: 5
	});
	$("#qunit-fixture").syoInputGrid("remove", 0);
	$("#qunit-fixture").syoInputGrid("add");
	
	deepEqual($("#qunit-fixture input:last").val(), "5", "The last input index is correct");
	
	$("#qunit-fixture").syoInputGrid("destroy");
});
test("Method remove(index) - Removing by index should show the emptyMessage when needed", function() {
	$("#qunit-fixture").syoInputGrid({
		itemTemplate: "<input type='text' value='$i' />",
		items: 0,
		emptyMessage: "Any message"
	});
	$("#qunit-fixture").syoInputGrid("add");
	$("#qunit-fixture").syoInputGrid("remove", 0);
	
	deepEqual($("#qunit-fixture div.grid-custom-msg").length, 1, "The emptyMessage should be appended");
	
	$("#qunit-fixture").syoInputGrid("destroy");
});
test("Method disabled - disable all input:text inside the container", function() {
	
	$("#qunit-fixture").syoInputGrid();
	$("#qunit-fixture").syoInputGrid("add", 2);
	$("#qunit-fixture").syoInputGrid("disabled");
	
	$("#qunit-fixture > input").each(function() {
		deepEqual($(this).prop("disabled"), true, "Input should be disabled");
	});
	
	$("#qunit-fixture").syoInputGrid("destroy");
});
test("Method disabled - When disabled no new input can be added", function() {
	$("#qunit-fixture").syoInputGrid();
	$("#qunit-fixture").syoInputGrid("add", 2);
	$("#qunit-fixture").syoInputGrid("disabled");
	
	$("#qunit-fixture").syoInputGrid("add", 2);
	
	expect(3);
	$("#qunit-fixture > input").each(function() {
		ok(true, "When disabled no new input can be added");
	});
	
	$("#qunit-fixture").syoInputGrid("destroy");
});
test("Method disabled - When disabled no input can be removed", function() {
	$("#qunit-fixture").syoInputGrid();
	$("#qunit-fixture").syoInputGrid("add", 2);
	$("#qunit-fixture").syoInputGrid("disabled");
	
	$("#qunit-fixture").syoInputGrid("remove");
	
	expect(3);
	$("#qunit-fixture > input").each(function() {
		ok(true, "When disabled no new input can be added");
	});
	
	$("#qunit-fixture").syoInputGrid("destroy");
});
test("Method enabled - enable all input:text inside the container", function() {
	$("#qunit-fixture").syoInputGrid();
	$("#qunit-fixture").syoInputGrid("add", 2);
	$("#qunit-fixture").syoInputGrid("disabled");
	$("#qunit-fixture").syoInputGrid("enabled");
	
	$("#qunit-fixture > input").each(function() {
		deepEqual($(this).prop("disabled"), false, "Input should not be disabled");
	});
	
	$("#qunit-fixture").syoInputGrid("destroy");
});