module("Properties");
test("Property 'itemTemplate' - should replace $i for the item index", function() {
	$("#qunit-fixture").syoInputGrid({
		itemTemplate: "<input name='testName$i' id='testID$i'></input>"
	});
	
	deepEqual($("#qunit-fixture input").attr("id"), "testID0", "ID is correct");
	deepEqual($("#qunit-fixture input").attr("name"), "testName0", "name is correct");
	
	$("#qunit-fixture").syoInputGrid("destroy");
});
test("Property 'items' - should create more than one item", function() {
	$("#qunit-fixture").syoInputGrid({
		items: 3
	});
	
	expect(3);
	$("#qunit-fixture > input").each(function() {
		ok(true, "The input has been sucessfuly created");
	});
	
	$("#qunit-fixture").syoInputGrid("destroy");
});
test("Property 'items' - should create more than one item", function() {
	$("#qunit-fixture").syoInputGrid({
		items: 3
	});
	
	expect(3);
	$("#qunit-fixture > input").each(function() {
		ok(true, "The input has been sucessfuly created");
	});
	
	$("#qunit-fixture").syoInputGrid("destroy");
});
test("Property 'items' - passing string array", function() {
	$("#qunit-fixture").syoInputGrid({
		items: ["first input", "second input"]
	});
	
	deepEqual($("#qunit-fixture > input:eq(0)").val(), "first input", "Input is correct");
	deepEqual($("#qunit-fixture > input:eq(1)").val(), "second input", "Input is correct");
	
	$("#qunit-fixture").syoInputGrid("destroy");
});
test("Property 'items' - passing string array using 'ignoreFirst === true'", function() {
	$("#qunit-fixture").syoInputGrid({
		items: ["first input", "second input"],
		ignoreFirst: true
	});
	
	deepEqual($("#qunit-fixture > input:eq(0)").val(), "first input", "Input is correct");
	deepEqual($("#qunit-fixture > input:eq(1)").val(), "second input", "Input is correct");
	
	$("#qunit-fixture").syoInputGrid("destroy");
});
test("Property 'items' - passing object array", function() {
	$("#qunit-fixture").syoInputGrid({
		items: [{
			value: "test-value",
			id: "test-id"
		}],
	});
	
	deepEqual($("#qunit-fixture > input:eq(0)").val(), "test-value", "Input is correct");
	deepEqual($("#qunit-fixture > input:eq(0)").attr("id"), "test-id", "Input is correct");
	
	$("#qunit-fixture").syoInputGrid("destroy");
});
test("Property 'type' - define which kind of input is being used", 11, function() {
	
	function getItem(createInput) {
		var select =	"<div>";
			select +=		"<select name='$i'>";
			select +=			"<option value=''>empty</option>";
			select +=			"<option value='value1'>v1</option>";
			select +=			"<option value='value2'>v2</option>";
			select +=			"<option value='value3'>v3</option>";
			select +=			"<option value='value4'>v4</option>";
			select += 		"</select>";
			select += createInput ? "<input id='test_input' type='text' />" : "";
			select +=	"</div>";
		return select;
	}
	
	$("#qunit-fixture").append(function() {
		return getItem(true) + getItem();
	});
	
	$("#qunit-fixture").syoInputGrid({
		type: "select-one",
		itemTemplate: getItem(),
		items: 0
	});
	
	$("#qunit-fixture").syoInputGrid("add");
	
	deepEqual($("#qunit-fixture").children().length, 3, "Should have 3 children");
	deepEqual($("#qunit-fixture select").length, 3, "Should have 3 selects");
	deepEqual($("#qunit-fixture select:eq(2)").attr("name"), "2", "The third select created should have the index 2");
	
	$("#qunit-fixture").syoInputGrid("disabled");
	$("#qunit-fixture select").each(function(index) {
		deepEqual($(this).prop("disabled"), true, "The select on index '" + index + "' should be disabled");
	});
	deepEqual($("#test_input").prop("disabled"), false, "Should not disable input elements");
	
	$("#test_input").prop("disabled", true);
	
	$("#qunit-fixture").syoInputGrid("enabled");
	$("#qunit-fixture select").each(function(index) {
		deepEqual($(this).prop("disabled"), false, "The select on index '" + index + "' should be enabled");
	});
	deepEqual($("#test_input").prop("disabled"), true, "Should not enable input elements");
	
	$("#qunit-fixture").syoInputGrid("destroy");
});
test("Property 'ignoreFirst' - should ignore the first add", function() {
	$("#qunit-fixture").syoInputGrid({
		ignoreFirst: true
	});
	
	expect(0);
	$("#qunit-fixture > input").each(function() {
		ok(false, "Should have no input");
	});
	
	$("#qunit-fixture").syoInputGrid("destroy");
});
test("Property 'ignoreFirst' - should be ignored if 'items' is defined", function() {
	$("#qunit-fixture").syoInputGrid({
		items: 2,
		ignoreFirst: true
	});
	
	expect(2);
	$("#qunit-fixture > input").each(function() {
		ok(true, "The input has been sucessfuly created");
	});
	
	$("#qunit-fixture").syoInputGrid("destroy");
});
test("Property 'emptyMessage'", function() {
	
	$("#qunit-fixture").syoInputGrid({
		emptyMessage: "Custom message"
	});
	
	$("#qunit-fixture").syoInputGrid("remove", "all");
	deepEqual($("#qunit-fixture > div.grid-custom-msg").text(), "Custom message", "The custom message has been sucessfully appended");
	
	$("#qunit-fixture").syoInputGrid("add");
	notDeepEqual($("#qunit-fixture > div.grid-custom-msg").text(), undefined, "The custom message has been sucessfully removed");
	
	$("#qunit-fixture").syoInputGrid("remove");
	deepEqual($("#qunit-fixture > div.grid-custom-msg").text(), "Custom message", "The custom message has been sucessfully appended");
	
	$("#qunit-fixture").syoInputGrid("destroy");
});
test("Property 'emptyMessage' on init (if ignoreFirst === true)", function() {
	$("#qunit-fixture").syoInputGrid({
		emptyMessage: "Custom message",
		ignoreFirst: true
	});
	
	deepEqual($("#qunit-fixture > div.grid-custom-msg").text(), "Custom message", "The custom message has been sucessfully appended");
	
	$("#qunit-fixture").syoInputGrid("destroy");
});
test("Property 'emptyMessage' - if children already exists count it to check if there is no items", function() {
	$("#qunit-fixture").append("<div class='an-item'></div>");
	$("#qunit-fixture").syoInputGrid({
		itemTemplate: "<div class='an-item'></div>",
		emptyMessage: "Custom message",
		ignoreFirst: true
	});
	
	deepEqual($("#qunit-fixture div.grid-custom-msg").length, 0, "The emptyMessage div should not exist");
	
	$("#qunit-fixture").syoInputGrid("destroy");
});
test("Property 'empty Message' - No default value, if not specified prints nothing", function() {
	$("#qunit-fixture").syoInputGrid({
		itemTemplate: "<div class='an-item'></div>",
		ignoreFirst: true
	});
	
	deepEqual($("#qunit-fixture div.grid-custom-msg").length, 0, "The emptyMessage div should not exist");
	deepEqual($("#qunit-fixture").text(), "", "The cpntent should be empty");
	
	$("#qunit-fixture").syoInputGrid("destroy");
});